@@ -93,7 +93,7 @@ class Swimmer:
         
 
     def __repr__(self) -> str:
-        return self.full_name
+        return self.full_pref_name
 
     @property
     def full_name(self):
@@ -102,6 +102,10 @@ class Swimmer:
         else:
             return f"{self.last_name}, {self.first_name}"
 
+    @property
+    def full_pref_name(self):
+        return f"{self.last_name}, {self.pref_name}"
+
 class Team:
     name: str
     code: str
@@ -254,6 +258,10 @@ def read(input):
                 splits = []
 
 
+    swimmer.events = events
+    swimmers.append(swimmer)
+    swimmer = None
+    team.swimmers = swimmers
     meet.teams.append(team)
 
     return meet
