@@ -231,7 +231,8 @@ class IndividualEventRecord(SDIFRecord):
     event_distance: str
     stroke: str
     event_number: str
-    event_age: str
+    event_lower_age: str
+    event_upper_age: str
     date: str
     seed_time: str
     seed_course: str
@@ -265,7 +266,8 @@ class IndividualEventRecord(SDIFRecord):
         "event_distance": (67,71),
         "stroke": (71,72),
         "event_number": (72,76),
-        "event_age": (76,80),
+        "event_lower_age": (76,78),
+        "event_upper_age": (78,80),
         "date": (80,88),
         "seed_time": (88,96),
         "seed_course": (96,97),
